[dovecot-cvs]
dovecot/src/lib-storage/index/dbox dbox-format.h, 1.1,
1.1.2.1 dbox-list.c, 1.6, 1.6.2.1 dbox-storage.c, 1.15.2.2, 1.15.2.3
cras at dovecot.org
cras at dovecot.org
Thu May 18 12:38:05 EEST 2006
Update of /var/lib/cvs/dovecot/src/lib-storage/index/dbox
In directory talvi:/tmp/cvs-serv5698/lib-storage/index/dbox
Modified Files:
Tag: branch_1_0
dbox-format.h dbox-list.c dbox-storage.c
Log Message:
Renamed Mails -> dbox-Mails to make it less likely to conflict with
user-created mailbox.
Index: dbox-format.h
===================================================================
RCS file: /var/lib/cvs/dovecot/src/lib-storage/index/dbox/dbox-format.h,v
retrieving revision 1.1
retrieving revision 1.1.2.1
diff -u -d -r1.1 -r1.1.2.1
--- dbox-format.h 12 Apr 2006 16:52:02 -0000 1.1
+++ dbox-format.h 18 May 2006 09:38:02 -0000 1.1.2.1
@@ -3,7 +3,7 @@
#define DBOX_SUBSCRIPTION_FILE_NAME "dovecot.subscriptions"
#define DBOX_INDEX_PREFIX "dovecot.index"
-#define DBOX_MAILDIR_NAME "Mails"
+#define DBOX_MAILDIR_NAME "dbox-Mails"
#define DBOX_MAIL_FILE_PREFIX "msg."
#define DBOX_MAIL_FILE_FORMAT DBOX_MAIL_FILE_PREFIX"%u"
Index: dbox-list.c
===================================================================
RCS file: /var/lib/cvs/dovecot/src/lib-storage/index/dbox/dbox-list.c,v
retrieving revision 1.6
retrieving revision 1.6.2.1
diff -u -d -r1.6 -r1.6.2.1
--- dbox-list.c 12 Apr 2006 16:52:02 -0000 1.6
+++ dbox-list.c 18 May 2006 09:38:02 -0000 1.6.2.1
@@ -226,7 +226,7 @@
if (len > 5 && strcmp(fname+len-5, ".lock") == 0)
return 0;
- /* skip Mails/ dir */
+ /* skip dbox-Mails/ dir */
if (strcmp(fname, DBOX_MAILDIR_NAME) == 0)
return 0;
@@ -241,7 +241,7 @@
if ((match = imap_match(ctx->glob, list_path)) < 0)
return 0;
- /* first as an optimization check if it contains Mails/ directory.
+ /* first as an optimization check if it contains dbox-Mails/ directory.
that means it's a directory and it contains mails. */
real_path = t_strconcat(ctx->dir->real_path, "/", fname, NULL);
mail_path = t_strconcat(real_path, "/"DBOX_MAILDIR_NAME, NULL);
Index: dbox-storage.c
===================================================================
RCS file: /var/lib/cvs/dovecot/src/lib-storage/index/dbox/dbox-storage.c,v
retrieving revision 1.15.2.2
retrieving revision 1.15.2.3
diff -u -d -r1.15.2.2 -r1.15.2.3
--- dbox-storage.c 12 May 2006 08:12:56 -0000 1.15.2.2
+++ dbox-storage.c 18 May 2006 09:38:02 -0000 1.15.2.3
@@ -132,7 +132,7 @@
data = t_strcut(data, ':');
- path = t_strconcat(data, "/inbox/Mails", NULL);
+ path = t_strconcat(data, "/inbox/"DBOX_MAILDIR_NAME, NULL);
if (stat(path, &st) < 0) {
if (debug)
i_info("dbox autodetect: stat(%s) failed: %m", path);
@@ -177,7 +177,7 @@
sizeof(DBOX_MAILDIR_NAME)-1) == 0 &&
(p[sizeof(DBOX_MAILDIR_NAME)-1] == '\0' ||
p[sizeof(DBOX_MAILDIR_NAME)-1] == '/')) {
/* don't allow the Mails directory to be
used as part of the mask */
return FALSE;
}
@@ -655,7 +655,7 @@
}
index_mailbox_check_add(&mbox->ibox,
- t_strconcat(mbox->path, "/Mails", NULL));
+ t_strconcat(mbox->path, "/"DBOX_MAILDIR_NAME, NULL));
}
struct mail_storage dbox_storage = {
More information about the dovecot-cvs
@@ -177,7 +177,7 @@
(p[sizeof(DBOX_MAILDIR_NAME)-1] == '\0' ||
p[sizeof(DBOX_MAILDIR_NAME)-1] == '/')) {
- /* don't allow the Mails directory to be
+ /* don't allow the dbox-Mails directory to be
used as part of the mask */
return FALSE;
mailing list